pyxmpp2.client

Package pyxmpp2 :: Module client |
[hide private]

# Module client

Basic XMPP-IM client implementation.

Normative reference:
  - RFC 6120
  - RFC 6121 (TODO: roster and presence management)

Classes | [hide private]
| Client Base class for an XMPP-IM client.

Functions | [hide private]
base_client_handlers_factory(settings) Build the default value for the `base_client_handlers setting` |

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.client")`